@@ -48,16 +48,16 @@ typedef struct {
 
 static int timer_tag;
 
-static EXPANDO_REC *char_expandos[127];
+static EXPANDO_REC *char_expandos[255];
 static GHashTable *expandos;
 static time_t client_start_time;
 static char *last_sent_msg, *last_sent_msg_body;
 static char *last_privmsg_from, *last_public_from;
-static char *sysname, *sysrelease;
+static char *sysname, *sysrelease, *sysarch;
 static const char *timestamp_format;
 
-#define CHAR_EXPANDOS_COUNT \
-	((int) (sizeof(char_expandos) / sizeof(char_expandos[0])))
+#define CHAR_EXPANDO(chr) \
+	(char_expandos[(int) (unsigned char) chr])
 
 /* Create expando - overrides any existing ones. */
 void expando_create(const char *key, EXPANDO_FUNC func, ...)
@@ -73,7 +73,7 @@ void expando_create(const char *key, EXPANDO_FUNC func, ...)
 		rec = g_hash_table_lookup(expandos, key);
 	else {
 		/* single character expando */
-		rec = char_expandos[(int) *key];
+		rec = CHAR_EXPANDO(*key);
 	}
 
 	if (rec != NULL)
@@ -83,7 +83,7 @@ void expando_create(const char *key, EXPANDO_FUNC func, ...)
                 if (key[1] != '\0')
 			g_hash_table_insert(expandos, g_strdup(key), rec);
 		else
-			char_expandos[(int) *key] = rec;
+			char_expandos[(int) (unsigned char) *key] = rec;
 	}
 
 	rec->func = func;
@@ -99,7 +99,7 @@ static EXPANDO_REC *expando_find(const char *key)
 	if (key[1] != '\0')
 		return g_hash_table_lookup(expandos, key);
         else
-		return char_expandos[(int) *key];
+		return CHAR_EXPANDO(*key);
 }
 
 /* Add new signal to expando */
@@ -136,16 +136,16 @@ void expando_destroy(const char *key, EXPANDO_FUNC func)
 
 	if (key[1] == '\0') {
 		/* single character expando */
-		rec = char_expandos[(int) *key];
+		rec = CHAR_EXPANDO(*key);
 		if (rec != NULL && rec->func == func) {
-			char_expandos[(int) *key] = NULL;
+			char_expandos[(int) (unsigned char) *key] = NULL;
 			g_free(rec);
 		}
 	} else if (g_hash_table_lookup_extended(expandos, key, &origkey,
 						(gpointer *) &rec)) {
 		if (rec->func == func) {
-			g_free(origkey);
 			g_hash_table_remove(expandos, key);
+			g_free(origkey);
 			g_free(rec);
 		}
 	}
@@ -211,10 +211,8 @@ void expando_unbind(const char *key, int funccount, SIGNAL_FUNC *funcs)
 
 EXPANDO_FUNC expando_find_char(char chr)
 {
-	g_return_val_if_fail(chr < CHAR_EXPANDOS_COUNT, NULL);
-
-	return char_expandos[(int) chr] == NULL ? NULL :
-		char_expandos[(int) chr]->func;
+	return CHAR_EXPANDO(chr) == NULL ? NULL :
+		CHAR_EXPANDO(chr)->func;
 }
 
 EXPANDO_FUNC expando_find_long(const char *key)
@@ -381,6 +379,12 @@ static char *expando_sysrelease(SERVER_REC *server, void *item, int *free_ret)
         return sysrelease;
 }
 
+/* system architecture */
+static char *expando_sysarch(SERVER_REC *server, void *item, int *free_ret)
+{
+        return sysarch;
+}
+
 /* Topic of active channel (or address of queried nick) */
 static char *expando_topic(SERVER_REC *server, void *item, int *free_ret)
 {
@@ -454,11 +458,12 @@ void expandos_init(void)
 	last_sent_msg = NULL; last_sent_msg_body = NULL;
 	last_privmsg_from = NULL; last_public_from = NULL;
 
-        sysname = sysrelease = NULL;
+        sysname = sysrelease = sysarch = NULL;
 #ifdef HAVE_SYS_UTSNAME_H
-	if (uname(&un) == 0) {
+	if (uname(&un) >= 0) {
 		sysname = g_strdup(un.sysname);
 		sysrelease = g_strdup(un.release);
+		sysarch = g_strdup(un.machine);
 	}
 #endif
 
@@ -526,6 +531,8 @@ void expandos_init(void)
 		       "", EXPANDO_NEVER, NULL);
 	expando_create("sysrelease", expando_sysrelease,
 		       "", EXPANDO_NEVER, NULL);
+	expando_create("sysarch", expando_sysarch,
+		       "", EXPANDO_NEVER, NULL);
 	expando_create("topic", expando_topic,
 		       "window changed", EXPANDO_ARG_NONE,
 		       "window item changed", EXPANDO_ARG_WINDOW,
@@ -551,11 +558,12 @@ void expandos_deinit(void)
 {
 	int n;
 
-	for (n = 0; n < CHAR_EXPANDOS_COUNT; n++)
+	for (n = 0; n < sizeof(char_expandos)/sizeof(char_expandos[0]); n++)
 		g_free_not_null(char_expandos[n]);
 
 	expando_destroy("sysname", expando_sysname);
 	expando_destroy("sysrelease", expando_sysrelease);
+	expando_destroy("sysarch", expando_sysarch);
 	expando_destroy("topic", expando_topic);
 	expando_destroy("tag", expando_servertag);
 	expando_destroy("chatnet", expando_chatnet);
@@ -565,6 +573,7 @@ void expandos_deinit(void)
 	g_free_not_null(last_sent_msg); g_free_not_null(last_sent_msg_body);
 	g_free_not_null(last_privmsg_from); g_free_not_null(last_public_from);
 	g_free_not_null(sysname); g_free_not_null(sysrelease);
+        g_free_not_null(sysarch);
 
         g_source_remove(timer_tag);
 	signal_remove("message public", (SIGNAL_FUNC) sig_message_public);
