@@ -28,7 +28,8 @@ void server_setup_fill_reconn(SERVER_CONNECT_REC *conn,
    `dest' is either a server address or chat network */
 SERVER_CONNECT_REC *
 server_create_conn(int chat_type, const char *dest, int port,
-		   const char *password, const char *nick);
+		   const char *chatnet, const char *password,
+		   const char *nick);
 
 /* Find matching server from setup. Try to find record with a same port,
    but fallback to any server with the same address. */
