@@ -321,7 +321,7 @@ static void cmd_nick(const char *data, IRC_SERVER_REC *server, WI_ITEM_REC *item
 
 	nick = g_strdup_printf("%s :%s", nick, nick);
 	server_redirect_event(SERVER(server), nick, 5,
-			      "event nick", "nickchange over", 0,
+			      "event nick", "nickchange over", -1,
 			      "event 433", "nickchange over", 1,
 			      /* 437: ircnet = target unavailable,
 				      dalnet = banned in channel,
@@ -970,7 +970,6 @@ void irc_commands_init(void)
 {
 	tmpstr = g_string_new(NULL);
 
-	settings_add_str("misc", "quit_message", "leaving");
 	settings_add_str("misc", "part_message", "");
 	settings_add_int("misc", "knockout_time", 300);
 	settings_add_str("misc", "wall_format", "[Wall/$0] $1-");
